==> tomcat-plugin-1.2.2-sources.jar: com/xebialabs/deployit/plugin/tomcat/step/TomcatDeploymentStepBase.java <==
/*
 * Copyright (c) 2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to  (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.tomcat.step;

import org.apache.commons.lang.StringUtils;

import com.xebialabs.deployit.ci.artifact.NamedDeployableArtifact;
import com.xebialabs.deployit.ci.artifact.War;
import com.xebialabs.deployit.plugin.tomcat.ci.TomcatServer;

@SuppressWarnings("serial")
public abstract class TomcatDeploymentStepBase extends TomcatStepBase {

	protected NamedDeployableArtifact artifact;

	protected TomcatDeploymentStepBase(TomcatServer server, NamedDeployableArtifact artifact, String contextRoot) {
		super(server, contextRoot);
		this.artifact = artifact;
	}

	protected String getArtifactTargetFileName() {
		String targetFileName = artifact.getName();
		if (artifact instanceof War) {
			targetFileName += ".war";
		} else {
			throw new IllegalArgumentException("Artifact " + artifact + " is not a WAR");
		}
		return targetFileName;
	}

	protected String getExplodedWarTargetFileName() {
		if (artifact instanceof War) {
			return artifact.getName();
		} else {
			throw new IllegalArgumentException("Artifact " + artifact + " is not a WAR");
		}
	}

	protected String getDeployedArtifactPath() {
		if (!StringUtils.isBlank(contextRoot)) {
			return server.getAppBase() + server.getHost().getFileSeparator() + getArtifactTargetFileName();
		} else {
			return server.getDeployDirPath() + server.getHost().getFileSeparator() + getArtifactTargetFileName();
		}
	}

}

==> tomcat-plugin-1.3.2-sources.jar: com/xebialabs/deployit/plugin/tomcat/step/TomcatDeploymentStepBase.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.tomcat.step;

import org.apache.commons.lang.StringUtils;

import com.xebialabs.deployit.ci.artifact.NamedDeployableArtifact;
import com.xebialabs.deployit.ci.artifact.War;
import com.xebialabs.deployit.plugin.tomcat.ci.TomcatServer;
import com.xebialabs.deployit.plugin.tomcat.ci.TomcatWarMapping;

@SuppressWarnings("serial")
public abstract class TomcatDeploymentStepBase extends TomcatStepBase {

	protected NamedDeployableArtifact artifact;

	protected TomcatDeploymentStepBase(TomcatServer server, TomcatWarMapping mapping) {
		super(server, mapping);
		this.artifact = mapping.getSource();
	}

	protected String getArtifactTargetFileName() {
		checkArtifactIsWar();
		return artifact.getName() + ".war";
	}

	protected String getExplodedWarTargetFileName() {
		checkArtifactIsWar();

		if (isContextSet()) {
			return server.getDeployDirPath() + server.getHost().getFileSeparator() + contextRoot;
		} else {
			return server.getDeployDirPath() + server.getHost().getFileSeparator() + artifact.getName();
		}
	}

	protected String getDeployedArtifactPath() {
		return getArtifactDeploymentDirectory() + server.getHost().getFileSeparator() + getArtifactTargetFileName();
	}

	protected String getArtifactDeploymentDirectory() {
		if (!StringUtils.isBlank(mapping.getContextRoot()) && !StringUtils.isBlank(mapping.getAppBase())) {
			return mapping.getAppBase();
		} else {
			return server.getDeployDirPath();
		}
	}

	protected void checkArtifactIsWar() {
		if (!(artifact instanceof War))
			throw new IllegalArgumentException("Artifact " + artifact + " is not a WAR");

	}

}
